pub enum IppValue {
Show 20 variants Integer(i32), Enum(i32), OctetString(String), TextWithoutLanguage(String), NameWithoutLanguage(String), Charset(String), NaturalLanguage(String), Uri(String), UriScheme(String), RangeOfInteger { min: i32, max: i32, }, Boolean(bool), Keyword(String), Array(Vec<IppValue>), Collection(Vec<IppValue>), MimeMediaType(String), DateTime { year: u16, month: u8, day: u8, hour: u8, minutes: u8, seconds: u8, deci_seconds: u8, utc_dir: char, utc_hours: u8, utc_mins: u8, }, MemberAttrName(String), Resolution { cross_feed: i32, feed: i32, units: i8, }, NoValue, Other { tag: u8, data: Bytes, },
}
IPP attribute values as defined in RFC 8010

Variants

Integer(i32)

Enum(i32)

OctetString(String)

TextWithoutLanguage(String)

NameWithoutLanguage(String)

Charset(String)

NaturalLanguage(String)

Uri(String)

UriScheme(String)

RangeOfInteger

Fields

min: i32
max: i32

Boolean(bool)

Keyword(String)

Array(Vec<IppValue>)

Collection(Vec<IppValue>)

MimeMediaType(String)

DateTime

Fields

year: u16
month: u8
day: u8
hour: u8
minutes: u8
seconds: u8
deci_seconds: u8
utc_dir: char
utc_hours: u8
utc_mins: u8

MemberAttrName(String)

Resolution

Fields

cross_feed: i32
feed: i32
units: i8

NoValue

Other

Fields

tag: u8
data: Bytes

Implementations

Optionally returns mutable references to the inner fields if this is a IppValue::Integer, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Integer, otherwise None

Returns the inner fields if this is a IppValue::Integer, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Enum, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Enum, otherwise None

Returns the inner fields if this is a IppValue::Enum, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::OctetString, otherwise None

Optionally returns references to the inner fields if this is a IppValue::OctetString, otherwise None

Returns the inner fields if this is a IppValue::OctetString, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::TextWithoutLanguage, otherwise None

Optionally returns references to the inner fields if this is a IppValue::TextWithoutLanguage, otherwise None

Returns the inner fields if this is a IppValue::TextWithoutLanguage, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::NameWithoutLanguage, otherwise None

Optionally returns references to the inner fields if this is a IppValue::NameWithoutLanguage, otherwise None

Returns the inner fields if this is a IppValue::NameWithoutLanguage, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Charset, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Charset, otherwise None

Returns the inner fields if this is a IppValue::Charset, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::NaturalLanguage, otherwise None

Optionally returns references to the inner fields if this is a IppValue::NaturalLanguage, otherwise None

Returns the inner fields if this is a IppValue::NaturalLanguage, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Uri, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Uri, otherwise None

Returns the inner fields if this is a IppValue::Uri, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::UriScheme, otherwise None

Optionally returns references to the inner fields if this is a IppValue::UriScheme, otherwise None

Returns the inner fields if this is a IppValue::UriScheme, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::RangeOfInteger, otherwise None

Optionally returns references to the inner fields if this is a IppValue::RangeOfInteger, otherwise None

Returns the inner fields if this is a IppValue::RangeOfInteger, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Boolean, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Boolean, otherwise None

Returns the inner fields if this is a IppValue::Boolean, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Keyword, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Keyword, otherwise None

Returns the inner fields if this is a IppValue::Keyword, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Array, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Array, otherwise None

Returns the inner fields if this is a IppValue::Array, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Collection, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Collection, otherwise None

Returns the inner fields if this is a IppValue::Collection, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::MimeMediaType, otherwise None

Optionally returns references to the inner fields if this is a IppValue::MimeMediaType, otherwise None

Returns the inner fields if this is a IppValue::MimeMediaType, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::DateTime, otherwise None

Optionally returns references to the inner fields if this is a IppValue::DateTime, otherwise None

Returns the inner fields if this is a IppValue::DateTime, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::MemberAttrName, otherwise None

Optionally returns references to the inner fields if this is a IppValue::MemberAttrName, otherwise None

Returns the inner fields if this is a IppValue::MemberAttrName, otherwise returns back the enum in the Err case of the result

Optionally returns mutable references to the inner fields if this is a IppValue::Resolution, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Resolution, otherwise None

Returns the inner fields if this is a IppValue::Resolution, otherwise returns back the enum in the Err case of the result

Returns true if this is a IppValue::NoValue, otherwise false

Optionally returns mutable references to the inner fields if this is a IppValue::Other, otherwise None

Optionally returns references to the inner fields if this is a IppValue::Other, otherwise None

Returns the inner fields if this is a IppValue::Other, otherwise returns back the enum in the Err case of the result

Convert to binary tag

Parse value from byte array which does not include the value length field

Write value to byte array, including leading value length field, excluding value tag